@@ -1,7 +1,7 @@
 (*
  * libbrlapi - A library providing access to braille terminals for applications.
  *
- * Copyright (C) 2002-2022 by
+ * Copyright (C) 2002-2024 by
  *   Sébastien Hinderer <Sebastien.Hinderer@ens-lyon.org>
  *   Samuel Thibault <Samuel.Thibault@ens-lyon.org>
  * All rights reserved.
@@ -350,6 +350,7 @@ val param_computer_braille_row_cells : int
 val param_computer_braille_table : int
 val param_literary_braille_table : int
 val param_message_locale : int
+val param_driver_property_value : int
 val param_count : int
 val param_type_string : int
 val param_type_boolean : int
@@ -513,6 +514,8 @@ val cmd_say_higher : int32
 val cmd_say_all : int32
 val cmd_contracted : int32
 val cmd_compbrl6 : int32
+val cmd_prefreset : int32
+val cmd_aspk_emp_line : int32
 val blk_route : int32
 val blk_clip_new : int32
 val blk_cutbegin : int32
@@ -546,6 +549,7 @@ val blk_route_line : int32
 val blk_refresh_line : int32
 val blk_txtsel_start : int32
 val blk_txtsel_set : int32
+val blk_route_speech : int32
 val blk_selectvt : int32
 val blk_alert : int32
 val blk_passchar : int32
@@ -555,6 +559,8 @@ val blk_passxt : int32
 val blk_passps2 : int32
 val blk_context : int32
 val blk_touch_at : int32
+val blk_macro : int32
+val blk_hostcmd : int32
 val key_flg_toggle_on : int32
 val key_flg_toggle_off : int32
 val key_flg_motion_route : int32
@@ -567,6 +573,7 @@ val key_flg_input_meta : int32
 val key_flg_input_altgr : int32
 val key_flg_input_gui : int32
 val key_flg_input_escaped : int32
+val key_flg_input_capslock : int32
 val key_flg_kbd_release : int32
 val key_flg_kbd_emul0 : int32
 val key_flg_kbd_emul1 : int32
